/**
 * Marks a class to use an isolated cache.
 *
 * This is useful if the class has multiple instances (e.g., `TRANSIENT` scope) and you want each instance
 * to have its own separate cache space for the same methods, avoiding sharing cached data across instances.
 *
 * If your class has a single instance (e.g., `SINGLETON` scope), or if you want all instances of the class
 * to share the same cache space, this decorator should not be applied.
 */
export declare function IsolatedCache(): <T extends new (...args: any[]) => object>(target: T) => any;
//# sourceMappingURL=isolated-cache.decorator.d.ts.map