"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IsolatedCache = IsolatedCache;
const constants_1 = require("../constants");
/**
 * Marks a class to use an isolated cache.
 *
 * This is useful if the class has multiple instances (e.g., `TRANSIENT` scope) and you want each instance
 * to have its own separate cache space for the same methods, avoiding sharing cached data across instances.
 *
 * If your class has a single instance (e.g., `SINGLETON` scope), or if you want all instances of the class
 * to share the same cache space, this decorator should not be applied.
 */
function IsolatedCache() {
    return function (target) {
        target[constants_1.CACHE_INSTANCES_PROPERTY] = 0;
        return class IsolatedCacheClass extends target {
            constructor(...args) {
                super(...args);
                Object.defineProperty(IsolatedCacheClass, 'name', {
                    enumerable: false,
                    writable: false,
                    configurable: true,
                    value: target.name,
                });
                Object.defineProperty(this, constants_1.CACHE_INSTANCE_ID_PROPERTY, {
                    enumerable: false,
                    writable: false,
                    configurable: false,
                    value: ++target[constants_1.CACHE_INSTANCES_PROPERTY],
                });
            }
        };
    };
}
//# sourceMappingURL=isolated-cache.decorator.js.map