"use strict";
var LruCacheModule_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.LruCacheModule = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@nestjs/common");
const lru_cache_1 = require("lru-cache");
const constants_1 = require("./constants");
/**
 * LRU cache module.
 *
 * Must be registered using on of the following static methods:
 * - `register` - Registers the module synchronously.
 * - `registerAsync` - Registers the module asynchronously.
 */
let LruCacheModule = LruCacheModule_1 = class LruCacheModule {
    /**
     * Registers the LRU cache module synchronously.
     *
     * @param options LRU cache options.
     */
    static register(options) {
        const optionsProvider = {
            provide: constants_1.LRU_CACHE_OPTIONS,
            useValue: options,
        };
        const lruCache = {
            provide: constants_1.LRU_CACHE,
            useValue: new lru_cache_1.LRUCache(options),
        };
        return {
            global: options.isGlobal,
            module: LruCacheModule_1,
            providers: [optionsProvider, lruCache],
            exports: [constants_1.LRU_CACHE],
        };
    }
    /**
     * Registers the LRU cache module asynchronously.
     *
     * Requires one of the following factories: `useFactory`, `useClass`, or `useExisting`.
     *
     * @param options LRU cache async options.
     */
    static registerAsync(options) {
        var _a;
        const lruCache = {
            provide: constants_1.LRU_CACHE,
            useFactory: (opts) => new lru_cache_1.LRUCache(opts),
            inject: [constants_1.LRU_CACHE_OPTIONS],
        };
        return {
            global: options.isGlobal,
            imports: (_a = options.imports) !== null && _a !== void 0 ? _a : [],
            module: LruCacheModule_1,
            providers: [...LruCacheModule_1._createOptionsProviders(options), lruCache],
            exports: [constants_1.LRU_CACHE],
        };
    }
    static _createOptionsProviders(options) {
        var _a;
        if ((_a = options.useExisting) !== null && _a !== void 0 ? _a : options.useFactory) {
            return [LruCacheModule_1._createOptionsProvider(options)];
        }
        return [
            LruCacheModule_1._createOptionsProvider(options),
            {
                provide: options.useClass,
                useClass: options.useClass,
            },
        ];
    }
    static _createOptionsProvider(options) {
        var _a, _b;
        if (options.useFactory) {
            return {
                provide: constants_1.LRU_CACHE_OPTIONS,
                useFactory: options.useFactory,
                inject: (_a = options.inject) !== null && _a !== void 0 ? _a : [],
            };
        }
        return {
            provide: constants_1.LRU_CACHE_OPTIONS,
            useFactory: (factory) => tslib_1.__awaiter(this, void 0, void 0, function* () { return yield factory.createLruCacheOptions(); }),
            inject: [(_b = options.useExisting) !== null && _b !== void 0 ? _b : options.useClass],
        };
    }
};
exports.LruCacheModule = LruCacheModule;
exports.LruCacheModule = LruCacheModule = LruCacheModule_1 = tslib_1.__decorate([
    (0, common_1.Module)({})
], LruCacheModule);
//# sourceMappingURL=lru-cache.module.js.map